marktools.BendAfter
===================

.. inheritance-diagram:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter
   :private-bases:

.. autoclass:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.format

.. autoattribute:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.bend_amount

Methods
-------

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.attach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.detach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__eq__

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__str__
